@@ -77,12 +77,19 @@
 #'   To turn off, set `pdf=FALSE`.
 #'
 #'
-#' @param report_includes_files *Whether report.qmd includes \{\{< include chapter.qmd >\}\}*
+#' @param report_includes_files *Whether report.qmd includes \{\{< include 'chapter.qmd' >\}\}*
 #'
 #'   `scalar<logical>` // *default:* `FALSE`
 #'
 #'   Useful to have in mesos reports. However, bear in mind that including other qmd files with conflicting YAML-headers might be risky.
 #'
+#'
+#' @param report_includes_prefix,report_includes_suffix *Strings around files in report.qmd*
+#'
+#'   `scalar<string>` // *default:* `"\{\{< include "` and `" >\}\}"`
+#'
+#'   The prefix and suffix for each of the chapters being included in the report.qmd file if `report_includes_files = TRUE`.
+#'
 #' @param chapter_qmd_start_section_filepath,chapter_qmd_end_section_filepath,index_qmd_start_section_filepath,index_qmd_end_section_filepath,report_qmd_start_section_filepath,report_qmd_end_section_filepath, *Path to qmd-bit for start/end of each qmd*
 #'
 #'   `scalar<character>` // *default:* `NULL` (`optional`)
@@ -127,6 +134,13 @@
 #'  that prefixes should end with a `\n` as headings must begin on a new line.
 #'
 #'
+#' @param write_qmd *Toggle whether to make qmd-files*
+#'
+#'   `scalar<logical>` // *default:* `TRUE`
+#'
+#'   Sometimes it is useful to only create chapter_dataset files if these have been updated,
+#'   without having to overwrite the qmd files.
+#'
 #' @param attach_chapter_dataset *Toggle inclusion of chapter-specific datasets in qmd-files*
 #'
 #'   `scalar<logical>` // *default:* `FALSE`
@@ -179,7 +193,6 @@
 #'   `scalar<string>` // *default:* `"data_"`
 #'
 #'
-#'
 #' @importFrom rlang !!!
 #'
 #' @return The `path`-argument.
@@ -235,13 +248,15 @@ draft_report <-
            require_common_categories = TRUE, # Not in use, should be merged with chunk_templates?
            # Formats and attachments
            combined_report = TRUE,
+           write_qmd = TRUE,
            attach_chapter_dataset = TRUE,
            auxiliary_variables = NULL,
            serialized_format = c("rds", "qs"), # For attach_chapter_dataset
            max_path_warning_threshold = 260, # Tidy up argument name: max_width_path_warning. Keep here
-           # Debugging
            filename_prefix = "",
            data_filename_prefix = "data_",
+           report_includes_prefix = '{{< include "',
+           report_includes_suffix = '" >}}',
            log_file = NULL) {
     args <- utils::modifyList(
       as.list(environment()),
@@ -270,6 +285,7 @@ draft_report <-
         chapter_yaml_file = args$chapter_yaml_file,
         chapter_qmd_start_section_filepath = args$chapter_qmd_start_section_filepath,
         chapter_qmd_end_section_filepath = args$chapter_qmd_end_section_filepath,
+        write_qmd = args$write_qmd,
         attach_chapter_dataset = args$attach_chapter_dataset,
         auxiliary_variables = args$auxiliary_variables,
         serialized_format = args$serialized_format
@@ -293,6 +309,8 @@ draft_report <-
           authors = all_authors,
           output_formats = NULL,
           output_filename = NULL,
+          includes_prefix = report_includes_prefix,
+          includes_suffix = report_includes_suffix,
           call = rlang::caller_env()
         )
       processed_files <- c(processed_files, report_filepath)
