@@ -51,10 +51,13 @@ validate_draft_report_args <- function(params) {
       suffix_heading_for_group = list(fun = function(x) is.null(x) || (is.character(x) && rlang::is_named(x) && sum(duplicated(names(x))) == 0)),
       filename_prefix = list(fun = function(x) is_string(x) || is.null(x)),
       data_filename_prefix = list(fun = function(x) is_string(x) || is.null(x)),
+      report_includes_prefix = list(fun = function(x) is_string(x)),
+      report_includes_suffix = list(fun = function(x) is_string(x)),
       log_file = list(fun = function(x) is.null(x) || is_string(x)),
 
 
       # Boolean
+      write_qmd = list(fun = is_bool),
       attach_chapter_dataset = list(fun = is_bool),
       require_common_categories = list(fun = is_bool),
       combined_report = list(fun = is_bool),
